Changelog
---------

0.0.2 (2017-10-26)
~~~~~~~~~~~~~~~~~~

* Added conditional task execution.
* Added URL support for includes and imports.
* Added support for macros in includes and imports.
* Added exit with task error return code.
* Added task referencing in task definition.

0.0.1 (2017-10-18)
~~~~~~~~~~~~~~~~~~

Initial release.
